@@ -3,7 +3,6 @@ from datetime import date
 from pprint import pprint
 
 # rcpch imports
-from .bmi_functions import bmi_from_height_weight, weight_for_bmi_height
 from .centile_bands import centile_band_for_centile
 from .constants import *
 from .date_calculations import (chronological_decimal_age, corrected_decimal_age,
@@ -22,6 +21,12 @@ class Measurement:
         sex: str,
         gestation_days: int = 0,
         gestation_weeks: int = 0,
+        event_text: list = None,
+        bone_age: float = None,
+        bone_age_type: str = None,
+        bone_age_sds: float = None,
+        bone_age_centile: float = None,
+        bone_age_text: str = None
     ):
         """
         The Measurement Class is the gatekeeper to all the functions in the RCPCHGrowth package, although the public
@@ -37,6 +42,15 @@ class Measurement:
         `gestation_weeks`: (integer) gestation at birth in weeks.
         `gestation_days`: (integer) supplemental days in addition to gestation_weeks at birth.
         `reference`: ENUM refering to which reference dataset to use: ['uk-who', 'turners-syndrome', 'trisomy-21'].
+        `height_prediction`: decimal years
+        `height_prediction_sds`: SDS for height prediction against reference
+        `height_prediction_centile`: centile for height prediction against reference
+        `height_prediction_reference`: enum ['bayley-pinneau', 'roche-wainer-thissen']
+        `event_text`: list. this is a list of strings which are comments to tag a given measurement/plot with contextual information 
+        `bone_age`: an estimated skeletal age calculated from xrays reported in decimal years
+        `bone_age_sds`: an SDS for the bone age, based on references
+        `bone_age_centile`: a centile for the bone age, based on references
+        `bone_age_reference`: enum ['greulich-pyle', 'tanner-whitehouse-ii', 'tanner-whitehouse-iii', 'fels', 'bonexpert']
         """
 
         self.birth_date = birth_date
@@ -47,6 +61,16 @@ class Measurement:
         self.observation_value = observation_value
         self.reference = reference
         self.sex = sex
+        self.bone_age = bone_age
+        self.bone_age_type = bone_age_type
+        self.bone_age_sds = bone_age_sds
+        self.bone_age_centile = bone_age_centile
+        self.bone_age_text = bone_age_text
+        # self.height_prediction = height_prediction
+        # self.height_prediction_sds = height_prediction_sds
+        # self.height_prediction_centile = height_prediction_centile
+        # self.height_prediction_reference = height_prediction_reference
+        self.event_text = event_text
 
         try:
             self.__validate_measurement_method(
@@ -82,6 +106,8 @@ class Measurement:
             "chronological_decimal_age_data": {
                 "x": self.ages_object['measurement_dates']['chronological_decimal_age'],
                 "y": self.observation_value,
+                "b": self.bone_age,
+                "bone_age_label": f"SDS: {self.bone_age_sds}, Centile: {self.bone_age_type}",
                 "observation_error": self.calculated_measurements_object['child_observation_value']["observation_value_error"],
                 "age_type": "chronological_age",
                 "calendar_age": self.ages_object["measurement_dates"]["chronological_calendar_age"],
@@ -95,6 +121,8 @@ class Measurement:
             "corrected_decimal_age_data": {
                 "x": self.ages_object['measurement_dates']['corrected_decimal_age'],
                 "y": self.observation_value,
+                "b": self.bone_age,
+                "bone_age_label": f"SDS: {self.bone_age_sds}, Centile: {self.bone_age_type}",
                 "observation_error": self.calculated_measurements_object['child_observation_value']["observation_value_error"],
                 "age_type": "corrected_age",
                 "corrected_gestational_age": corrected_gestational_age,
@@ -111,6 +139,8 @@ class Measurement:
             "chronological_decimal_age_data": {
                 "x": self.ages_object['measurement_dates']['chronological_decimal_age'],
                 "y": self.calculated_measurements_object['measurement_calculated_values']["chronological_sds"],
+                "b": self.bone_age,
+                "bone_age_label": f"SDS: {self.bone_age_sds}, Centile: {self.bone_age_type}",
                 "age_type": "chronological_age",
                 "calendar_age": self.ages_object["measurement_dates"]["chronological_calendar_age"],
                 "lay_comment": self.ages_object["measurement_dates"]["comments"]["lay_chronological_decimal_age_comment"],
@@ -122,6 +152,8 @@ class Measurement:
             "corrected_decimal_age_data": {
                 "x": self.ages_object['measurement_dates']['corrected_decimal_age'],
                 "y": self.calculated_measurements_object['measurement_calculated_values']["corrected_sds"],
+                "b": self.bone_age,
+                "bone_age_label": f"SDS: {self.bone_age_sds}, Centile: {self.bone_age_type}",
                 "age_type": "corrected_age",
                 "corrected_gestational_age": corrected_gestational_age,
                 "calendar_age": self.ages_object["measurement_dates"]["corrected_calendar_age"],
@@ -142,6 +174,22 @@ class Measurement:
             'plottable_data': {
                 "centile_data": self.plottable_centile_data,
                 "sds_data": self.plottable_sds_data
+            },
+            # 'height_prediction_data':{
+            #     "height_prediction": self.height_prediction,
+            #     "height_prediction_sds": self.height_prediction_sds,
+            #     "height_prediction_centile": self.height_prediction_centile,
+            #     "height_prediction_reference": self.height_prediction_reference
+            # },
+            'bone_age': {
+                "bone_age": self.bone_age,
+                "bone_age_type": self.bone_age_type,
+                "bone_age_sds": self.bone_age_sds,
+                "bone_age_centile": self.bone_age_centile,
+                "bone_age_text": self.bone_age_text,
+            },
+            'event_data': {
+                'event_text': self.event_text
             }
         }
 
@@ -237,7 +285,7 @@ class Measurement:
         
         corrected_percentage_median_bmi = None
         chronological_percentage_median_bmi = None
-        if measurement_method == "bmi" and corrected_age is not None and chronological_age is not None:
+        if measurement_method == BMI and corrected_age is not None and chronological_age is not None:
             try: 
                 corrected_percentage_median_bmi = percentage_median_bmi(
                 reference=reference,
